@@ -12,6 +12,8 @@
 #' @inheritParams crew::crew_client
 #' @inheritParams crew_launcher_lsf
 #' @inheritParams crew::crew_controller
+#' @param seconds_exit Deprecated on 2023-09-21 in version 0.1.2.9000.
+#'   No longer necessary.
 #' @examples
 #' if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
 #' controller <- crew_controller_lsf()
@@ -26,7 +28,7 @@ crew_controller_lsf <- function(
   workers = 1L,
   host = NULL,
   port = NULL,
-  tls = crew::crew_tls(),
+  tls = crew::crew_tls(mode = "automatic"),
   tls_enable = NULL,
   tls_config = NULL,
   seconds_interval = 0.25,
@@ -34,7 +36,7 @@ crew_controller_lsf <- function(
   seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
-  seconds_exit = 1,
+  seconds_exit = NULL,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
@@ -54,6 +56,14 @@ crew_controller_lsf <- function(
   lsf_memory_gigabytes_required = NULL,
   lsf_cores = NULL
 ) {
+  if (!is.null(seconds_exit)) {
+    crew::crew_deprecate(
+      name = "seconds_exit",
+      date = "2023-09-21",
+      version = "0.5.0.9002",
+      alternative = "none (no longer necessary)"
+    )
+  }
   client <- crew::crew_client(
     name = name,
     workers = workers,
@@ -67,11 +77,9 @@ crew_controller_lsf <- function(
   )
   launcher <- crew_launcher_lsf(
     name = name,
-    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
-    seconds_exit = seconds_exit,
     tasks_max = tasks_max,
     tasks_timers = tasks_timers,
     reset_globals = reset_globals,
