@@ -8,6 +8,8 @@
 #' @inheritParams crew::crew_client
 #' @inheritParams crew_launcher_sge
 #' @inheritParams crew::crew_controller
+#' @param seconds_exit Deprecated on 2023-09-21 in version 0.1.2.9000.
+#'   No longer necessary.
 #' @examples
 #' if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
 #' controller <- crew_controller_sge()
@@ -22,18 +24,22 @@ crew_controller_sge <- function(
   workers = 1L,
   host = NULL,
   port = NULL,
+  tls = crew::crew_tls(mode = "automatic"),
+  tls_enable = NULL,
+  tls_config = NULL,
   seconds_interval = 0.25,
   seconds_timeout = 10,
   seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
-  seconds_exit = 1,
+  seconds_exit = NULL,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
+  launch_max = 5L,
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
   command_delete = as.character(Sys.which("qdel")),
@@ -49,28 +55,38 @@ crew_controller_sge <- function(
   sge_cores = NULL,
   sge_gpu = NULL
 ) {
-  # TODO: remove eval parse after next crew release.
-  client <- eval(parse(text = "crew::crew_client"))(
+  if (!is.null(seconds_exit)) {
+    crew::crew_deprecate(
+      name = "seconds_exit",
+      date = "2023-09-21",
+      version = "0.5.0.9002",
+      alternative = "none (no longer necessary)"
+    )
+  }
+  client <- crew::crew_client(
     name = name,
     workers = workers,
     host = host,
     port = port,
+    tls = tls,
+    tls_enable = tls_enable,
+    tls_config = tls_config,
     seconds_interval = seconds_interval,
     seconds_timeout = seconds_timeout
   )
   launcher <- crew_launcher_sge(
     name = name,
-    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
-    seconds_exit = seconds_exit,
     tasks_max = tasks_max,
     tasks_timers = tasks_timers,
     reset_globals = reset_globals,
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
+    launch_max = launch_max,
+    tls = tls,
     verbose = verbose,
     command_submit = command_submit,
     command_delete = command_delete,
