@@ -37,7 +37,6 @@ crew_launcher_cluster <- function(
   seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
-  seconds_exit = 1,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
@@ -45,7 +44,7 @@ crew_launcher_cluster <- function(
   reset_options = FALSE,
   garbage_collection = FALSE,
   launch_max = 5L,
-  tls = crew::crew_tls(),
+  tls = crew::crew_tls(mode = "automatic"),
   verbose = FALSE,
   command_submit = "",
   command_delete = "",
@@ -59,7 +58,6 @@ crew_launcher_cluster <- function(
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
-    seconds_exit = seconds_exit,
     tasks_max = tasks_max,
     tasks_timers = tasks_timers,
     reset_globals = reset_globals,
@@ -108,7 +106,6 @@ crew_class_launcher_cluster <- R6::R6Class(
     #' @param seconds_launch See [crew_launcher_cluster()].
     #' @param seconds_idle See [crew_launcher_cluster()].
     #' @param seconds_wall See [crew_launcher_cluster()].
-    #' @param seconds_exit See [crew_launcher_cluster()].
     #' @param tasks_max See [crew_launcher_cluster()].
     #' @param tasks_timers See [crew_launcher_cluster()].
     #' @param reset_globals See [crew_launcher_cluster()].
@@ -128,7 +125,6 @@ crew_class_launcher_cluster <- R6::R6Class(
       seconds_launch = NULL,
       seconds_idle = NULL,
       seconds_wall = NULL,
-      seconds_exit = NULL,
       tasks_max = NULL,
       tasks_timers = NULL,
       reset_globals = NULL,
@@ -149,7 +145,6 @@ crew_class_launcher_cluster <- R6::R6Class(
         seconds_launch = seconds_launch,
         seconds_idle = seconds_idle,
         seconds_wall = seconds_wall,
-        seconds_exit = seconds_exit,
         tasks_max = tasks_max,
         tasks_timers = tasks_timers,
         reset_globals = reset_globals,
