@@ -62,11 +62,10 @@
 #'   `pbs_walltime_hours = NULL` omits this line.
 crew_launcher_pbs <- function(
   name = NULL,
-  seconds_interval = 0.25,
+  seconds_interval = NULL,
   seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
-  seconds_exit = 1,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
@@ -74,7 +73,7 @@ crew_launcher_pbs <- function(
   reset_options = FALSE,
   garbage_collection = FALSE,
   launch_max = 5L,
-  tls = crew::crew_tls(),
+  tls = crew::crew_tls(mode = "automatic"),
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
   command_delete = as.character(Sys.which("qdel")),
@@ -88,14 +87,21 @@ crew_launcher_pbs <- function(
   pbs_cores = NULL,
   pbs_walltime_hours = 12
 ) {
+  crew_deprecate(
+    name = "seconds_interval",
+    date = "2023-10-02",
+    version = "0.5.0.9003",
+    alternative = "none (no longer necessary)",
+    condition = "message",
+    value = seconds_interval,
+    frequency = "once"
+  )
   name <- as.character(name %|||% crew::crew_random_name())
   launcher <- crew_class_launcher_pbs$new(
     name = name,
-    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
-    seconds_exit = seconds_exit,
     tasks_max = tasks_max,
     tasks_timers = tasks_timers,
     reset_globals = reset_globals,
@@ -149,11 +155,9 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @description PBS/TORQUE launcher constructor.
     #' @return an PBS/TORQUE launcher object.
     #' @param name See [crew_launcher_pbs()].
-    #' @param seconds_interval See [crew_launcher_pbs()].
     #' @param seconds_launch See [crew_launcher_pbs()].
     #' @param seconds_idle See [crew_launcher_pbs()].
     #' @param seconds_wall See [crew_launcher_pbs()].
-    #' @param seconds_exit See [crew_launcher_pbs()].
     #' @param tasks_max See [crew_launcher_pbs()].
     #' @param tasks_timers See [crew_launcher_pbs()].
     #' @param reset_globals See [crew_launcher_pbs()].
@@ -176,11 +180,9 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @param pbs_walltime_hours See [crew_launcher_pbs()].
     initialize = function(
       name = NULL,
-      seconds_interval = NULL,
       seconds_launch = NULL,
       seconds_idle = NULL,
       seconds_wall = NULL,
-      seconds_exit = NULL,
       tasks_max = NULL,
       tasks_timers = NULL,
       reset_globals = NULL,
@@ -204,11 +206,9 @@ crew_class_launcher_pbs <- R6::R6Class(
     ) {
       super$initialize(
         name = name,
-        seconds_interval = seconds_interval,
         seconds_launch = seconds_launch,
         seconds_idle = seconds_idle,
         seconds_wall = seconds_wall,
-        seconds_exit = seconds_exit,
         tasks_max = tasks_max,
         tasks_timers = tasks_timers,
         reset_globals = reset_globals,
