@@ -64,11 +64,10 @@
 #'   `"#$ -l gpu=1"` in the SGE job script. `sge_gpu = NULL` omits this line.
 crew_launcher_sge <- function(
   name = NULL,
-  seconds_interval = 0.25,
+  seconds_interval = NULL,
   seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
-  seconds_exit = 1,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
@@ -76,7 +75,7 @@ crew_launcher_sge <- function(
   reset_options = FALSE,
   garbage_collection = FALSE,
   launch_max = 5L,
-  tls = crew::crew_tls(),
+  tls = crew::crew_tls(mode = "automatic"),
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
   command_delete = as.character(Sys.which("qdel")),
@@ -92,14 +91,21 @@ crew_launcher_sge <- function(
   sge_cores = NULL,
   sge_gpu = NULL
 ) {
+  crew_deprecate(
+    name = "seconds_interval",
+    date = "2023-10-02",
+    version = "0.5.0.9003",
+    alternative = "none (no longer necessary)",
+    condition = "message",
+    value = seconds_interval,
+    frequency = "once"
+  )
   name <- as.character(name %|||% crew::crew_random_name())
   launcher <- crew_class_launcher_sge$new(
     name = name,
-    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
-    seconds_exit = seconds_exit,
     tasks_max = tasks_max,
     tasks_timers = tasks_timers,
     reset_globals = reset_globals,
@@ -159,11 +165,9 @@ crew_class_launcher_sge <- R6::R6Class(
     #' @description SGE launcher constructor.
     #' @return an SGE launcher object.
     #' @param name See [crew_launcher_sge()].
-    #' @param seconds_interval See [crew_launcher_sge()].
     #' @param seconds_launch See [crew_launcher_sge()].
     #' @param seconds_idle See [crew_launcher_sge()].
     #' @param seconds_wall See [crew_launcher_sge()].
-    #' @param seconds_exit See [crew_launcher_sge()].
     #' @param tasks_max See [crew_launcher_sge()].
     #' @param tasks_timers See [crew_launcher_sge()].
     #' @param reset_globals See [crew_launcher_sge()].
@@ -188,11 +192,9 @@ crew_class_launcher_sge <- R6::R6Class(
     #' @param sge_gpu See [crew_launcher_sge()].
     initialize = function(
       name = NULL,
-      seconds_interval = NULL,
       seconds_launch = NULL,
       seconds_idle = NULL,
       seconds_wall = NULL,
-      seconds_exit = NULL,
       tasks_max = NULL,
       tasks_timers = NULL,
       reset_globals = NULL,
@@ -218,11 +220,9 @@ crew_class_launcher_sge <- R6::R6Class(
     ) {
       super$initialize(
         name = name,
-        seconds_interval = seconds_interval,
         seconds_launch = seconds_launch,
         seconds_idle = seconds_idle,
         seconds_wall = seconds_wall,
-        seconds_exit = seconds_exit,
         tasks_max = tasks_max,
         tasks_timers = tasks_timers,
         reset_globals = reset_globals,
