@@ -1,5 +1,4 @@
 test_that("crew_controller_sge() script() all lines", {
-  skip_if_low_dep_versions()
   x <- crew_controller_sge(
     script_lines = c("module load R", "echo 'start'"),
     sge_cwd = TRUE,
@@ -29,3 +28,10 @@ test_that("crew_controller_sge() script() all lines", {
   )
   expect_equal(out, exp)
 })
+
+test_that("deprecate seconds_exit", {
+  expect_warning(
+    x <- crew_controller_sge(seconds_exit = 1),
+    class = "crew_deprecate"
+  )
+})
