@@ -66,7 +66,7 @@ test_that("SGE subclass mock job creates a tempdir() job script", {
     "echo 'start'"
   )
   expect_equal(out[seq_along(exp)], exp)
-  x$terminate()
+  x$terminate_worker(x$workers$handle[[1L]])
   expect_false(file.exists(script))
 })
 
@@ -130,6 +130,6 @@ test_that("SGE subclass mock job creates a custom job script", {
     "echo 'start'"
   )
   expect_equal(out[seq_along(exp)], exp)
-  x$terminate()
+  x$terminate_worker(x$workers$handle[[1L]])
   expect_false(file.exists(script))
 })
